@@ -15,7 +15,7 @@ class WSGIRequest(DjangoWSGIRequest):
     """
 
     def __setattr__(self, attr, value):
-        if attr == 'user':
+        if attr == "user":
             pghistory.context(user=value.id if value else None)
 
         return super().__setattr__(attr, value)
@@ -28,9 +28,9 @@ def HistoryMiddleware(get_response):
     """
 
     def middleware(request):
-        if request.method in ('GET', 'POST', 'PUT', 'PATCH', 'DELETE'):
+        if request.method in ("GET", "POST", "PUT", "PATCH", "DELETE"):
             with pghistory.context(
-                user=request.user.pk if hasattr(request, 'user') else None,
+                user=request.user.pk if hasattr(request, "user") else None,
                 url=request.path,
             ):
                 if isinstance(request, DjangoWSGIRequest):  # pragma: no branch
